Pushover plugin for MonkeyCI. It allows you to create a job that sends a message to Pushover.
Pushover plugin for MonkeyCI. It allows you to create a job that sends a message to Pushover.
(default-poster conf)Default post function, sends a message to pushover using the postman api
Default post function, sends a message to pushover using the postman api
(pushover-action {:keys [msg] :as config} ctx)Job action fn that actually sends the message. This serves as the job action, but can be called directly, or integrated in other action jobs.
Job action fn that actually sends the message. This serves as the job action, but can be called directly, or integrated in other action jobs.
(pushover-msg {:keys [id] :or {id "pushover"} :as config})Creates an action job that sends the configured message to Pushover, using
configured credentials. These are either passed in using user and token,
or read from build parameters (default pushover-user and pushover-token).
Creates an action job that sends the configured message to Pushover, using configured credentials. These are either passed in using `user` and `token`, or read from build parameters (default `pushover-user` and `pushover-token`).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |